commit 44cc701
Author:     Noah Misch <noah@leadboat.com>
AuthorDate: Sat Jul 25 17:39:12 2015 -0400
Commit:     Noah Misch <noah@leadboat.com>
CommitDate: Sat Jul 25 17:39:12 2015 -0400

    MSVC: Future-proof installation file skip logic.
    
    This code relied on knowing exactly where in the source tree temporary
    installations might appear.  A reasonable hacker may not think to update
    this code when adding use of a temporary installation, making it
    fragile.  Observe that commit 9fa8b0ee90c44c0f97d16bf65e94322988c94864
    broke it unnoticed, and commit dcae5faccab64776376d354decda0017c648bb53
    fixed it unnoticed.  Back-patch to 9.5 only; use of temporary
    installations is unlikely to change in released versions.

diff --git a/src/tools/msvc/Install.pm b/src/tools/msvc/Install.pm
index b592f99..f955725 100644
--- a/src/tools/msvc/Install.pm
+++ b/src/tools/msvc/Install.pm
@@ -98,6 +98,9 @@ sub Install
 		{   wanted => sub {
 				/^.*\.sample\z/s
 				  && push(@$sample_files, $File::Find::name);
+
+				# Don't find files of in-tree temporary installations.
+				$_ eq 'share' and $File::Find::prune = 1;
 			  }
 		},
 		@top_dir);
@@ -152,6 +155,9 @@ sub Install
 			{   wanted => sub {
 					/^(.*--.*\.sql|.*\.control)\z/s
 					  && push(@$pl_extension_files, $File::Find::name);
+
+					# Don't find files of in-tree temporary installations.
+					$_ eq 'share' and $File::Find::prune = 1;
 				  }
 			},
 			@pldirs);
@@ -199,8 +205,6 @@ sub CopySetOfFiles
 	print "Copying $what" if $what;
 	foreach (@$flist)
 	{
-		next if /regress/;      # Skip temporary install in regression subdir
-		next if /ecpg.test/;    # Skip temporary install in regression subdir
 		my $tgt = $target . basename($_);
 		print ".";
 		lcopy($_, $tgt) || croak "Could not copy $_: $!\n";
